<?php
namespace PME\Controllers\Requisicao;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class RequisicaoAnalServController extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $environment;
    protected $birtStrategy;
    protected $utilities;
    protected $lista;
    protected $newCode;
    protected $connection;

    public function __construct(ReportService $reportService, $entityManager, $environment, $birtStrategy, $utilities, $lista, $newCode, $connection) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->birtStrategy  = $birtStrategy;
        $this->utilities     = $utilities;
        $this->lista         = $lista;
        $this->newCode       = $newCode;
        $this->connection    = $connection;

        parent::__construct($reportService);
    }

    protected $reportMapping = array (
      'PME00900' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                "CDFILCENTPME"  => "P_CDFILCENTPME",
                "NMFILCENTPME"  => "P_NMFILCENTPME",
                "SERVICO"       => "P_CDSERVFILI",
                "UNIDADE"       => "P_CDFILIAL",
                "CDOPERADOR"    => "P_CDOPERADOR",
                "NMOPERADOR"    => "P_NMOPERADOR",
                "DTDE"          => "P_DTINICIAL",
                "DTATE"         => "P_DTFINAL",
                "NRLISTA"       => "P_NRLISTA",
                "CDPICTPROD"    => "P_CDPICTPROD",
                "TAMNIV"        => "P_TAMNIV",
                "NRLINHABRANCA" => "P_NRLINHABRANCA",
                "QUEBRAPAG"     => "P_IDQUEBRAPAGINA",
                "CDARVPRODINI"  => "P_PRODINI",
                "CDARVPRODFIN"  => "P_PRODFIN",
                "NRORG"         => "P_NRORG"
            )
        ),
      'PME00902' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                "CDFILCENTPME"  => "P_CDFILCENTPME",
                "NMFILCENTPME"  => "P_NMFILCENTPME",
                "DTDE"          => "P_DTINICIAL",
                "DTATE"         => "P_DTFINAL",
                "TAMNIV"        => "P_TAMNIV",
                "CDGRUPFILI"    => "P_CDGRUPFILI",
                "NMGRUPFILI"    => "P_NMGRUPFILI",
                "UNIDADE"       => "P_CDFILIAL",
                "SERVICO"       => "P_CDSERVFILI",
                "CDOPERADOR"    => "P_CDOPERADOR",
                "NMOPERADOR"    => "P_NMOPERADOR",
                "CDPICTPROD"    => "P_CDPICTPROD",
                "NRLISTA"       => "P_NRLISTA",
                "NRLINHABRANCA" => "P_NRLINHABRANCA",
                "CDARVPRODINI"  => "P_PRODINI",
                "CDARVPRODFIN"  => "P_PRODFIN",
                "NRORG"         => "P_NRORG"
            )
        )  
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        try{
          $row = $request->getRow();
          $nrorg = $this->environment->getNrOrg();
          
          if(empty($row['CDARVPRODINI'])) $row['CDARVPRODINI'] = 0;
    
          if(empty($row['CDARVPRODFIN'])) $row['CDARVPRODFIN'] = "ZZZZZZZZZZ";
          else $row['CDARVPRODFIN'] = str_pad($row['CDARVPRODFIN'], 10, "Z", STR_PAD_RIGHT);
  
          if($row['CALCULAR']) $this->calculatePrevCons($request, $response);
          
          $row['CDOPERADOR'] = $this->environment->getCdOperador(); 
          $row['NMOPERADOR'] = $this->environment->getCurrentUserName(); 
          
          if($row['QUEBRAPAG'] === false) $row['QUEBRAPAG'] = 'N';
          else $row['QUEBRAPAG'] = 'S';
          
          if($row['QTDPROD'] === false) $row['QTDPROD'] = 'N';
          else $row['QTDPROD'] = 'S';
  
          if($row['UNIDADE'] === null){
            $row['UNIDADE'] = 'T';
          }
  
          if(empty($row['SERVICO'])){
            $row['SERVICO'] = 'T';
          } else if(is_array($row['SERVICO'])){
            $row['SERVICO'] = join("_", $row['SERVICO']);
          }
        
          if($row['TIPOCARD'] === null){
            // $tipoCard = join('_', $this->getTipoCard($row));
            // $row['NRLISTA'] = $this->lista->geraLista($tipoCard, $nrorg);
            $row['NRLISTA'] = $this->geraListaTipoCard($row);
          } else {
            $tipoCard = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']) : $row['TIPOCARD'];
            // $row['NRLISTA'] = $this->lista->geraLista($tipoCard, $nrorg); 
            $row['NRLISTA'] = $this->geraListaTipoCard($row);
          }
          
          if($row['ORDENA'] == 0) $row['TAMNIV'] = 10;
          else $row['TAMNIV'] = 0;
          
          $row['NRORG'] = $nrorg;
  
          $this->birtStrategy->setReportLocale($this->utilities->getLanguage());
          $this->birtStrategy->setReportFormat(strtolower($row['reportFormat']));
        } catch(\Exception $e) {
        $response->setError(new DTO\Response\Error($e->getMessage(), 1));
      }
    }
    
    public function calculatePrevCons(DTO\Request\Row $request, DTO\Response $response) {
      try{
        $row = $request->getRow();
        $nrconsplan = $this->procedurePrevCons($row);
        //$response->setMetadata(['nrconsplan' => $nrconsplan]);
        $this->insertIntoLogprevretipme($row, $nrconsplan);
      }catch(\Exception $e) {
        $response->setError(new DTO\Response\Error($e->getMessage(), 1));
      }
    }
    
    private function procedurePrevCons($row){
      $nrorg = $this->environment->getNrOrg();
      $row['CDOPERADOR'] = $this->environment->getCdOperador();
      $nrconsplan = $this->newCode->getCodeByTableName('CONSPLAN'.$row['CDFILCENTPME'], $nrorg);

      if(empty($row['UNIDADE'])){
        $cdfilial = null;
      }else $cdfilial = is_array($row['UNIDADE']) ? join("_", $row['UNIDADE']) : $row['UNIDADE'];
      
      if(empty($row['SERVICO'])){
        $cdservfili = null;
      } else $cdservfili = is_array($row['SERVICO']) ? join("_", $row['SERVICO']) : $row['SERVICO'];
      
      if(empty($row['TIPOCARD'])){
        $tipoCard = null;
      }else $tipoCard = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']) : $row['TIPOCARD'];
      
      if($row['QTDPROD'] === false) $row['QTDPROD'] = 'N';
      else $row['QTDPROD'] = 'S';

      $connection = $this->entityManager->getConnection();
      $procedureCons = new StoredProcedure($connection, 'PREVISAO_CONSUMO_PME');
  
      $procedureCons->addParam(new Param('P_CDFILCENTPME', Param::PARAM_INPUT, $row['CDFILCENTPME'], Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_CDTIPOCARD',   Param::PARAM_INPUT, $tipoCard,            Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_CDFILIAL',     Param::PARAM_INPUT, $cdfilial,            Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_CDSERVFILI',   Param::PARAM_INPUT, $cdservfili,          Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_DTINICIAL',    Param::PARAM_INPUT, $row['DTDE'],         Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_DTFINAL',      Param::PARAM_INPUT, $row['DTATE'],        Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_PEACRESCIMO',  Param::PARAM_INPUT, $row['ACRESCIMO'],    Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_CDPRODUTOINI', Param::PARAM_INPUT, $row['CDARVPRODINI'], Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_CDPRODUTOFIN', Param::PARAM_INPUT, $row['CDARVPRODFIN'], Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_CDOPERADOR',   Param::PARAM_INPUT, $row['CDOPERADOR'],   Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_DTHRCALCPC',   Param::PARAM_INPUT, date("d/m/Y"),        Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_NRCONSPLAN',   Param::PARAM_INPUT, $nrconsplan,          Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_IDARREDOND',   Param::PARAM_INPUT, $row['QTDPROD'],      Param::PARAM_TYPE_STR));
      $procedureCons->execute();
      return $nrconsplan;
    }
    
    private function getUnidades($row){
      $rows = $this->utilities->getUnidades($row['CDFILCENTPME']);
      $unidades = [];
      foreach($rows as $unid){
        array_push($unidades, $unid['CDFILIAL']);
      }
      return $unidades;
    }

    private function getTipoCard($row){
      $rows = $this->utilities->getTipoCard($row['CDFILCENTPME']);
      $tiposCard = [];
      foreach($rows as $tipo){
        array_push($tiposCard, $tipo['CDTIPOCARD']);
      }
      return $tiposCard;
    }
    
    private function insertIntoLogprevretipme($row, $nrconsplan) {
      try {
          if(empty($row['UNIDADE'])) $cdfilial = 'T';
          else $cdfilial = is_array($row['UNIDADE']) ? join("_", $row['UNIDADE']) : $row['UNIDADE'];
          
          if(empty($row['SERVICO'])) $cdservfili = 'T';
          else $cdservfili = is_array($row['SERVICO']) ? join("_", $row['SERVICO']) : $row['SERVICO'];
          
          if(empty($row['PRODINICIAL'])) $produtoIni = '0';
          else $produtoIni = is_array($row['PRODINICIAL']) ? $row['PRODINICIAL']["CDPRODUTO"] : '0';
          
          if(empty($row['PRODFINAL'])) $produtoFin = 'Z';
          else $produtoFin = is_array($row['PRODFINAL']) ? $row['PRODFINAL']["CDPRODUTO"] : 'Z';
          
          if(empty($row['TIPOCARD'])) $tpCardapio = 'T';
          else $tpCardapio = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']): 'T';
          
          $nrorg = $this->environment->getNrOrg();
          $this->connection->beginTransaction();
          
          $query = "INSERT INTO LOGPREVRETIPME ( CDFILCENTPME, CDTIPOCARD, CDSERVFILI, CDFILIAL, CDOPERADOR, DTHRCALCPR, DTINICIALPR, DTFINALPR, CDPRODINICPR, CDPRODFINAPR, PEACRESCIMPR, NRCONSPLANPR ) 
                          SELECT T.CDFILCENTPME, T.CDTIPOCARD, S.CDSERVFILI, F.CDFILIAL, :P_CDOPERADOR, :P_DTHRCALCPR, :P_DTINICIALPR, :P_DTFINALPR, :P_CDPRODINICPR, :P_CDPRODFINAPR, :P_PEACRESCIMPR, :P_NRCONSPLANPR 
                            FROM TIPOCARD       T 
                            INNER JOIN SERVTIPOCARD   S ON T.CDFILCENTPME = S.CDFILCENTPME 
                                   AND T.CDTIPOCARD = S.CDTIPOCARD
                                   AND S.NRORG = T.NRORG
                                   AND ( INSTR(:P_CDSERVFILI, S.CDSERVFILI) > 0 OR :P_CDSERVFILI = 'T' ) 
                            INNER JOIN FILITIPOCARD   F ON F.CDFILCENTPME = T.CDFILCENTPME 
                                   AND F.CDTIPOCARD = T.CDTIPOCARD 
                                   AND F.IDTCARATFILI = 'S'
                                   AND F.NRORG = T.NRORG
                                   AND ( INSTR(:P_CDFILIAL, F.CDFILIAL) > 0 OR :P_CDFILIAL = 'T' ) 
                                 WHERE T.CDFILCENTPME = :P_CDFILCENTPME 
                                   AND T.IDTPCARDATIV = 'S'
                                   AND T.NRORG = :P_NRORG
                                   AND ( T.CDTIPOCARD = :P_CDTIPOCARD OR :P_CDTIPOCARD IS NULL )";
            
          $params = array(
            'P_DTFINALPR'    => $row['DTATE'], 
            'P_CDFILIAL'     => $cdfilial,
            'P_CDOPERADOR'   => $row['CDOPERADOR'],
            'P_CDPRODFINAPR' => $produtoFin,
            'P_CDPRODINICPR' => $produtoIni,
            'P_NRCONSPLANPR' => $nrconsplan,
            'P_PEACRESCIMPR' => $row['ACRESCIMO'],
            'P_CDSERVFILI'   =>   $cdservfili,
            'P_CDFILCENTPME' => $row['CDFILCENTPME'],
            'P_DTHRCALCPR'   => date("d/m/Y H:i:s"),
            'P_DTINICIALPR'  => $row['DTDE'],
            'P_NRORG'        => $nrorg,
            'P_CDTIPOCARD'   => $tpCardapio,
          );
            
	        $this->connection->prepare($query)->execute($params);
	        $this->connection->commit();
	    } catch (\Exception $e) {
	    	$this->connection->rollback();
	    	throw $e;
		  }
    }
    
    private function geraListaTipoCard($row) {
    if(empty($row['TIPOCARD'])) $cdtipocard = 'T';
    else $cdtipocard = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']) : $row['TIPOCARD'];
    
    $nrorg = $this->environment->getNrOrg();
    
    $nrlista = $this->newCode->getCodeByTableName('LISTA', $nrorg);

    $sql = "INSERT INTO LISTA (CDLISTA, NRLISTA, NRORG)
              SELECT CDTIPOCARD, :NRLISTA AS NRLISTA, NRORG FROM TIPOCARD WHERE NRORG = :NRORG AND CDFILCENTPME = :CDFILCENTPME AND (NRPASTATCARD = :NRPASTATCARD OR :NRPASTATCARD IS NULL) 
              AND ( INSTR(:CDTIPOCARD, CDTIPOCARD) <> 0 OR ( :CDTIPOCARD = 'T' ) )
              ORDER BY CDTIPOCARD";
    $stmt = $this->entityManager->getConnection()->prepare($sql);
    $stmt->execute(
      array(
        "NRLISTA"      => $nrlista,
        "CDFILCENTPME" => $row['CDFILCENTPME'],
        "CDTIPOCARD" => $cdtipocard,
        "NRPASTATCARD"     => null,
        "NRORG" => $nrorg,
      )
    );
    
    return $nrlista;
  }
}