<?php
namespace PME\Modules\Planejamento\Prato;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class PercentualReceitaController {
    protected $utilities;
    protected $connection;
    protected $crudService;
    protected $dataSourceManager;
    protected $receita;
    protected $prato;
    
    public function __construct($utilities, $connection, $crudService, $dataSourceManager, $receita, $prato) {
        $this->utilities         = $utilities;
        $this->connection        = $connection;
        $this->crudService       = $crudService;
        $this->dataSourceManager = $dataSourceManager;
        $this->receita  = $receita;
        $this->prato  = $prato;
    }
    
    public function replicacao(DTO\Request $request, DTO\Response $response) {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->utilities->getNrOrg();
            
            $params = $request->getParameters();
            $rowOrigem = $params['rowO'];
            $rowFilterServ = $params['rowS'];
            $rowServicos = $params['checkedRows'];

            $filialD = $rowFilterServ['UNIDADE'];
            $prato = $rowOrigem['PRATOINICIAL']['CDPRATO'];
            $filAuxPrat = $rowOrigem['PRATOINICIAL']['CDFILAUXPRAT'];

            if ($rowOrigem['TPRECEITA'] == '') $tpReceita = $rowOrigem['TPRECEITA1'];
            else $tpReceita = $rowOrigem['TPRECEITA'];
            
            $cdfilcentpme = $rowOrigem['CDFILCENTPME'];
            
            foreach($rowServicos as $servico) {
                $percentual = $servico['PERCENTUAL'];
                if ($tpReceita === 'P') {
                    $filialO = 'X';
                    $servicoO = 'X';
                    $tpCardO = 'X';
                } else if ($tpReceita === 'L') {
                    $filialO = $rowOrigem['UNIDADE_ORIGEM'];
                    $servicoO = 'X';
                    $tpCardO = 'X';
                } else if ($tpReceita === 'T') {
                    $filialO = 'X';
                    $servicoO = 'X';
                    $tpCardO = $rowOrigem['TIPOCARD_ORIGEM'];
                } else { // Serviço
                    $filialO = $rowOrigem['UNIDADE_ORIGEM'];
                    $servicoO = $rowOrigem['SERVICO_ORIGEM'];
                    $tpCardO = 'X';
                }
                $servicoD = $servico['CDSERVFILI'];
                
                $dataSourceReceserv = 'receserv';
                $conditions = array(
        	        array(
        	            'columnName' => 'NRORG',
        	            'operator' => '=',
        	            'value' => $nrorg
        	        ),
        	        array(
        	            'columnName' => 'CDPRATO',
        	            'operator' => '=',
        	            'value' => $prato
        	        ),
        	        array(
        	            'columnName' => 'CDFILAUXPRAT',
        	            'operator' => '=',
        	            'value' => $filAuxPrat
        	        ),
        	        array(
        	            'columnName' => 'CDFILIAL',
        	            'operator' => '=',
        	            'value' => $filialD
        	        ),
        	        array(
        	            'columnName' => 'CDSERVFILI',
        	            'operator' => '=',
        	            'value' => $servicoD
        	        )
        	    );
                
                $produtosReceita = $this->crudService->getFilteredDataSet($dataSourceReceserv, $conditions);
                if ($produtosReceita && !empty($produtosReceita)) $this->dataSourceManager->delete($produtosReceita);
                
                $dataSourcePratserv = 'pratserv';
                //$dados = $this->crudService->getFilteredDataSet($dataSourcePratserv, $conditions)->getRows();
                $dados = $this->crudService->getFilteredDataSet($dataSourcePratserv, $conditions);
                if ($dados && !empty($dados)) $this->dataSourceManager->delete($dados);
                
                $dataSourceGramagem = 'pratogramag';
                $gramagem = $this->crudService->getFilteredDataSet($dataSourceGramagem, $conditions);
                if ($gramagem && !empty($gramagem)) $this->dataSourceManager->delete($gramagem);
                
                //INSERÇÕES
                // TIRA DA RECEITA DE ORIGEM OS PRODUTOS QUE NÃO SÃO ATIVOS NA FILIAL
                // DE DESTINO
                $newReq = new DTO\Request\Row('',"","","");
                $newReq->setParameter('plate', $prato);
                $newReq->setParameter('filAux', $filAuxPrat);
                switch ($tpReceita) {
                case 'P':
                    // $receitaO = $this->retornaReceita('recepadr', $prato, $filAuxPrat);
                    $receitaO = $this->receita->returnRecipePadrao($prato, $filAuxPrat);
                    $this->prato->returnPratpadr($newReq, $response);
                    $dadosReceitaO = $this->prato->getResponseLastDataSet($response)->getRows();
                    // $dadosReceitaO = $this->retornaReceita('pratpadr', $prato, $filAuxPrat);
                    break;
                case 'T':
                    // $receitaO = $this->retornaReceita('recetpcard', $prato, $filAuxPrat, $tpCardO);
                    $receitaO = $this->receita->returnRecipeTpCard($prato, $filAuxPrat, $tpCardO, $cdfilcentpme);
                    $newReq->setParameter('tipocard', $tpCardO);
                    $this->prato->returnPrattpcard($newReq, $response);
                    $dadosReceitaO = $this->prato->getResponseLastDataSet($response)->getRows();
                    // $dadosReceitaO = $this->retornaReceita('prattpcard', $prato, $filAuxPrat, $tpCardO);
                    break;
                case 'L':
                    // $receitaO = $this->retornaReceita('recefili', $prato, $filAuxPrat, $tpCardO, $filialO);
                    $receitaO = $this->receita->returnRecipeLocal($prato, $filAuxPrat, $filialO);
                    $newReq->setParameter('cdfilial', $filialO);
                    $this->prato->returnPratfili($newReq, $response);
                    $dadosReceitaO = $this->prato->getResponseLastDataSet($response)->getRows();
                    // $dadosReceitaO = $this->retornaReceita('pratfili', $prato, $filAuxPrat, $tpCardO, $filialO);
                    break;
                case 'S':
                    // $receitaO = $this->retornaReceita('receserv', $prato, $filAuxPrat, $tpCardO, $filialO, $servicoO);
                    $receitaO = $this->receita->returnRecipeServico($prato, $filAuxPrat, $filialO, $servicoO);
                    $newReq->setParameter('cdfilial', $filialO);
                    $newReq->setParameter('cdserv', $servicoO);
                    $this->prato->returnPratserv($newReq, $response);
                    $dadosReceitaO = $this->prato->getResponseLastDataSet($response)->getRows();
                    // $dadosReceitaO = $this->retornaReceita('pratserv', $prato, $filAuxPrat, $tpCardO, $filialO, $servicoO);
                    break;
                }
                
                if ($receitaO) {
                    foreach ($receitaO as $prodReceitaO) {
                        $produtoInserir = array(
                            'NRORG'        => $nrorg,
                            '__is_new'     => true,
                            'CDFILAUXPRAT' => $filAuxPrat,
                            'CDPRATO'      => $prato,
                            'CDFILIAL'     => $filialD,
                            'CDSERVFILI'   => $servicoD,
                            'CDTIPOCARD'   => $tpCardO,    
                            'CDPRODUTO'    => $prodReceitaO['CDPRODUTO'],
                            'SGUNIDADE'    => $prodReceitaO['SGUNIDADE']
                        );

                        switch ($tpReceita) {
                        case 'P':
                            $produtoInserir['QTPRODRECSER']    = $prodReceitaO['QTPRODPRAT']   * $percentual / 100;
                            $produtoInserir['VRPEFATCOCSE']    = $prodReceitaO['VRPEFATCOCPR'];
                            $produtoInserir['VRPEFATCORSE']    = $prodReceitaO['VRPEFATCORPR'];
                            $produtoInserir['QTBRUTASE']       = $prodReceitaO['QTBRUTAPR']    * $percentual / 100;
                            $produtoInserir['QTUNIDESTSE']     = $prodReceitaO['QTUNIDESTPR']  * $percentual / 100;
                            $produtoInserir['VRPEFATNUTSE']    = $prodReceitaO['VRPEFATNUTPR'];
                            $produtoInserir['QTCALCNUTRSE']    = $prodReceitaO['QTCALCNUTRPR'] * $percentual / 100;
                            $produtoInserir['QTBRUTASEUNR']    = $prodReceitaO['QTBRUTAPRUNR'] * $percentual / 100;
                            $produtoInserir['HRTEMPPREPSE']    = $prodReceitaO['HRTEMPPREPPR'];
                            $produtoInserir['IDPRODBASESE']    = $prodReceitaO['IDPRODBASEPR'];
                            $produtoInserir['IDQTDEFIXSE']     = $prodReceitaO['IDQTDEFIXPR'];
                            $produtoInserir['IDUTCOMPENTDIRS'] = $prodReceitaO['IDUTCOMPENTDIRP'];
                            $produtoInserir['QTCOMPLPRODSERV'] = $prodReceitaO['QTCOMPLPRODPADR'];
                            $produtoInserir['IDTPREQPRODSERV'] = $prodReceitaO['IDTPREQPRODPADR'];
                            $produtoInserir['CDAPRERECE']      = $prodReceitaO['CDAPRERECE'];
                            break;
                        case 'L':
                            $produtoInserir['QTPRODRECSER']    = $prodReceitaO['QTPRODRECLOC'] * $percentual / 100;
                            $produtoInserir['VRPEFATCOCSE']    = $prodReceitaO['VRPEFATCOCLO'];
                            $produtoInserir['VRPEFATCORSE']    = $prodReceitaO['VRPEFATCORLO'];
                            $produtoInserir['QTBRUTASE']       = $prodReceitaO['QTBRUTALO']    * $percentual / 100;
                            $produtoInserir['QTUNIDESTSE']     = $prodReceitaO['QTUNIDESTLO']  * $percentual / 100;
                            $produtoInserir['VRPEFATNUTSE']    = $prodReceitaO['VRPEFATNUTLO'];
                            $produtoInserir['QTCALCNUTRSE']    = $prodReceitaO['QTCALCNUTRLO'] * $percentual / 100;
                            $produtoInserir['QTBRUTASEUNR']    = $prodReceitaO['QTBRUTALOUNR'] * $percentual / 100;
                            $produtoInserir['HRTEMPPREPSE']    = $prodReceitaO['HRTEMPPREPLO'];
                            $produtoInserir['IDPRODBASESE']    = $prodReceitaO['IDPRODBASELO'];
                            $produtoInserir['IDQTDEFIXSE']     = $prodReceitaO['IDQTDEFIXLO'];
                            $produtoInserir['IDUTCOMPENTDIRS'] = $prodReceitaO['IDUTCOMPENTDIRF'];
                            $produtoInserir['QTCOMPLPRODSERV'] = $prodReceitaO['QTCOMPLPRODFILI'];
                            $produtoInserir['IDTPREQPRODSERV'] = $prodReceitaO['IDTPREQPRODFILI'];
                            $produtoInserir['CDAPRERECE']      = $prodReceitaO['CDAPRERECE'];
                            break;
                        case 'S':
                            $produtoInserir['QTPRODRECSER']    = $prodReceitaO['QTPRODRECSER'] * $percentual / 100;
                            $produtoInserir['VRPEFATCOCSE']    = $prodReceitaO['VRPEFATCOCSE'];
                            $produtoInserir['VRPEFATCORSE']    = $prodReceitaO['VRPEFATCORSE'];
                            $produtoInserir['QTBRUTASE']       = $prodReceitaO['QTBRUTASE']    * $percentual / 100;
                            $produtoInserir['QTUNIDESTSE']     = $prodReceitaO['QTUNIDESTSE']  * $percentual / 100;
                            $produtoInserir['VRPEFATNUTSE']    = $prodReceitaO['VRPEFATNUTSE'];
                            $produtoInserir['QTCALCNUTRSE']    = $prodReceitaO['QTCALCNUTRSE'] * $percentual / 100;
                            $produtoInserir['QTBRUTASEUNR']    = $prodReceitaO['QTBRUTASEUNR'] * $percentual / 100;
                            $produtoInserir['HRTEMPPREPSE']    = $prodReceitaO['HRTEMPPREPSE'];
                            $produtoInserir['IDPRODBASESE']    = $prodReceitaO['IDPRODBASESE'];
                            $produtoInserir['IDQTDEFIXSE']     = $prodReceitaO['IDQTDEFIXSE'];
                            $produtoInserir['IDUTCOMPENTDIRS'] = $prodReceitaO['IDUTCOMPENTDIRS'];
                            $produtoInserir['QTCOMPLPRODSERV'] = $prodReceitaO['QTCOMPLPRODSERV'];
                            $produtoInserir['IDTPREQPRODSERV'] = $prodReceitaO['IDTPREQPRODSERV'];
                            $produtoInserir['CDAPRERECE']      = $prodReceitaO['CDAPRERECE'];
                            break;
                        case 'T':
                            $produtoInserir['QTPRODRECSER']    = $prodReceitaO['QTPRODPRATTP'] * $percentual / 100;
                            $produtoInserir['VRPEFATCOCSE']    = $prodReceitaO['VRPEFATCOCPRTP'];
                            $produtoInserir['VRPEFATCORSE']    = $prodReceitaO['VRPEFATCORPRTP'];
                            $produtoInserir['QTBRUTASE']       = $prodReceitaO['QTBRUTAPRTP']    * $percentual / 100;
                            $produtoInserir['QTUNIDESTSE']     = $prodReceitaO['QTUNIDESTPRTP']  * $percentual / 100;
                            $produtoInserir['VRPEFATNUTSE']    = $prodReceitaO['VRPEFATNUTPRTP'];
                            $produtoInserir['QTCALCNUTRSE']    = $prodReceitaO['QTCALCNUTRPRTP'] * $percentual / 100;
                            $produtoInserir['QTBRUTASEUNR']    = $prodReceitaO['QTBRUTAPRUNRTP'] * $percentual / 100;
                            $produtoInserir['HRTEMPPREPSE']    = $prodReceitaO['HRTEMPPREPPRTP'];
                            $produtoInserir['IDPRODBASESE']    = $prodReceitaO['IDPRODBASEPRTP'];
                            $produtoInserir['IDQTDEFIXSE']     = $prodReceitaO['IDQTDEFIXPRTP'];
                            // $produtoInserir['IDUTCOMPENTDIRS'] = $prodReceitaO['IDUTCOMPENTDIRS'];
                            // $produtoInserir['QTCOMPLPRODSERV'] = $prodReceitaO['QTCOMPLPRODSERV'];
                            // $produtoInserir['IDTPREQPRODSERV'] = $prodReceitaO['IDTPREQPRODSERV'];
                            $produtoInserir['CDAPRERECE']      = $prodReceitaO['CDAPRERECE'];
                            break;
                        }
                        
                        $produtoInserir['VRPERCDEGELO'] = $prodReceitaO['VRPERCDEGELO'];

                        $requestInsertProduto
                            = new \Zeedhi\Framework\DTO\Request\Row(
                            $produtoInserir, '', '', ''
                        );
                        
                        $produtoInserir = $this->crudService->getRowsToSave(
                            $requestInsertProduto, "receserv"
                        );
                        
                        $this->crudService->save(
                            "receserv", $produtoInserir
                        );
                    }
                }
                
                // Insere dados da receita
                if ($dadosReceitaO && count($dadosReceitaO) > 0) {
                    $pratPadrInserir = array(
                        'NRORG'        => $nrorg,
                        '__is_new'     => true,
                        'CDFILAUXPRAT' => $filAuxPrat,
                        'CDPRATO'      => $prato,
                        'CDFILIAL'     => $filialD,
                        'CDSERVFILI'   => $servicoD
                    );
                    $dadosReceitaO = $dadosReceitaO[0];
                    
                    $pratPadrInserir['DSPRATO'] = $dadosReceitaO['DSPRATO'];
                    $pratPadrInserir['IDATIVO'] = $dadosReceitaO['IDATIVO'];
                    $pratPadrInserir['DTINATIVAUTO'] = $dadosReceitaO['DTINATIVAUTO'];

                    switch ($tpReceita) {
                        case 'P':
                            $pratPadrInserir['NRCORPRISERV']       = $dadosReceitaO['NRCORPRIPRAT'];
                            $pratPadrInserir['NRCORSEQSERV']       = $dadosReceitaO['NRCORSEQPRAT'];
                            $pratPadrInserir['NRCORAUXSERV']       = $dadosReceitaO['NRCORAUXPRAT'];
                            $pratPadrInserir['QTPADRAOSERV']       = $dadosReceitaO['QTPADRAOPRAT'] * $percentual / 100;
                            $pratPadrInserir['QTCONTAISERV']       = $dadosReceitaO['QTCONTAIPRAT'];
                            $pratPadrInserir['HRVALCONSERV']       = $dadosReceitaO['HRVALCONPRAT'];
                            $pratPadrInserir['NMFANTASIASE']       = $dadosReceitaO['NMFANTASIAPR'];
                            $pratPadrInserir['QTCARBOPRSER']       = $dadosReceitaO['QTCARBOPRPAD'];
                            $pratPadrInserir['QTLIPIDPRSER']       = $dadosReceitaO['QTLIPIDPRPAD'];
                            $pratPadrInserir['QTPROTEPRSER']       = $dadosReceitaO['QTPROTEPRPAD'];
                            $pratPadrInserir['QTCALORPRSER']       = $dadosReceitaO['QTCALORPRPAD'];
                            $pratPadrInserir['QTALCOOPRSER']       = $dadosReceitaO['QTALCOOPRPAD'];
                            $pratPadrInserir['VRPEMINSERV']        = $dadosReceitaO['VRPEMINPADR'];
                            $pratPadrInserir['QTAMOSTRSERV']       = $dadosReceitaO['QTAMOSTRPADR'];
                            $pratPadrInserir['CDPRODPRODUCAO']     = $dadosReceitaO['CDPRODPRODUCAO'];
                            $pratPadrInserir['QTLIMSEGSERV']       = $dadosReceitaO['QTLIMSEGPADR'];
                            $pratPadrInserir['IDPRODCHILL']        = $dadosReceitaO['IDPRODCHILL'];
                            $pratPadrInserir['IDTPPRODCHILL']      = $dadosReceitaO['IDTPPRODCHILL'];
                            $pratPadrInserir['IDFINALSERV']        = $dadosReceitaO['IDFINALPADR'];
                            $pratPadrInserir['CDMEDICASE']         = $dadosReceitaO['CDMEDICASE'];
                            $pratPadrInserir['QTMEDICASEPRATSERV'] = $dadosReceitaO['QTMEDICASEPRATPADR'];
                            break;
                        case 'L':
                            $pratPadrInserir['NRCORPRISERV']       = $dadosReceitaO['NRCORPRIFILI'];
                            $pratPadrInserir['NRCORSEQSERV']       = $dadosReceitaO['NRCORSEQFILI'];
                            $pratPadrInserir['NRCORAUXSERV']       = $dadosReceitaO['NRCORAUXFILI'];
                            $pratPadrInserir['QTPADRAOSERV']       = $dadosReceitaO['QTPADRAOFILI'] * $percentual / 100;
                            $pratPadrInserir['QTCONTAISERV']       = $dadosReceitaO['QTCONTAIFILI'];
                            $pratPadrInserir['HRVALCONSERV']       = $dadosReceitaO['HRVALCONFILI'];
                            $pratPadrInserir['NMFANTASIASE']       = $dadosReceitaO['NMFANTASIAPF'];
                            $pratPadrInserir['QTCARBOPRSER']       = $dadosReceitaO['QTCARBOPRFIL'];
                            $pratPadrInserir['QTLIPIDPRSER']       = $dadosReceitaO['QTLIPIDPRFIL'];
                            $pratPadrInserir['QTPROTEPRSER']       = $dadosReceitaO['QTPROTEPRFIL'];
                            $pratPadrInserir['QTCALORPRSER']       = $dadosReceitaO['QTCALORPRFIL'];
                            $pratPadrInserir['QTALCOOPRSER']       = $dadosReceitaO['QTALCOOPRFIL'];
                            $pratPadrInserir['VRPEMINSERV']        = $dadosReceitaO['VRPEMINFILI'];
                            $pratPadrInserir['QTAMOSTRSERV']       = $dadosReceitaO['QTAMOSTRFILI'];
                            $pratPadrInserir['CDPRODPRODUCAO']     = $dadosReceitaO['CDPRODPRODUCAO'];
                            $pratPadrInserir['QTLIMSEGSERV']       = $dadosReceitaO['QTLIMSEGFILI'];
                            $pratPadrInserir['IDPRODCHILL']        = $dadosReceitaO['IDPRODCHILL'];
                            $pratPadrInserir['IDTPPRODCHILL']      = $dadosReceitaO['IDTPPRODCHILL'];
                            $pratPadrInserir['IDFINALSERV']        = $dadosReceitaO['IDFINALFILI'];
                            $pratPadrInserir['CDMEDICASE']         = $dadosReceitaO['CDMEDICASE'];
                            $pratPadrInserir['QTMEDICASEPRATSERV'] = $dadosReceitaO['QTMEDICASEPRATFILI'];
                        break;
                        case 'S':
                            $pratPadrInserir['NRCORPRISERV']       = $dadosReceitaO['NRCORPRISERV'];
                            $pratPadrInserir['NRCORSEQSERV']       = $dadosReceitaO['NRCORSEQSERV'];
                            $pratPadrInserir['NRCORAUXSERV']       = $dadosReceitaO['NRCORAUXSERV'];
                            $pratPadrInserir['QTPADRAOSERV']       = $dadosReceitaO['QTPADRAOSERV'] * $percentual / 100;
                            $pratPadrInserir['QTCONTAISERV']       = $dadosReceitaO['QTCONTAISERV'];
                            $pratPadrInserir['HRVALCONSERV']       = $dadosReceitaO['HRVALCONSERV'];
                            $pratPadrInserir['NMFANTASIASE']       = $dadosReceitaO['NMFANTASIASE'];
                            $pratPadrInserir['QTCARBOPRSER']       = $dadosReceitaO['QTCARBOPRSER'];
                            $pratPadrInserir['QTLIPIDPRSER']       = $dadosReceitaO['QTLIPIDPRSER'];
                            $pratPadrInserir['QTPROTEPRSER']       = $dadosReceitaO['QTPROTEPRSER'];
                            $pratPadrInserir['QTCALORPRSER']       = $dadosReceitaO['QTCALORPRSER'];
                            $pratPadrInserir['QTALCOOPRSER']       = $dadosReceitaO['QTALCOOPRSER'];
                            $pratPadrInserir['VRPEMINSERV']        = $dadosReceitaO['VRPEMINSERV'];
                            $pratPadrInserir['QTAMOSTRSERV']       = $dadosReceitaO['QTAMOSTRSERV'];
                            $pratPadrInserir['CDPRODPRODUCAO']     = $dadosReceitaO['CDPRODPRODUCAO'];
                            $pratPadrInserir['QTLIMSEGSERV']       = $dadosReceitaO['QTLIMSEGSERV'];
                            $pratPadrInserir['IDPRODCHILL']        = $dadosReceitaO['IDPRODCHILL'];
                            $pratPadrInserir['IDTPPRODCHILL']      = $dadosReceitaO['IDTPPRODCHILL'];
                            $pratPadrInserir['IDFINALSERV']        = $dadosReceitaO['IDFINALSERV'];
                            $pratPadrInserir['CDMEDICASE']         = $dadosReceitaO['CDMEDICASE'];
                            $pratPadrInserir['QTMEDICASEPRATSERV'] = $dadosReceitaO['QTMEDICASEPRATSERV'];
                        break;
                        case 'T':
                            $pratPadrInserir['NRCORPRISERV']       = $dadosReceitaO['NRCORPRIPRATTP'];
                            // $pratPadrInserir['NRCORSEQSERV']       = $dadosReceitaO['NRCORSEQFILI'];
                            // $pratPadrInserir['NRCORAUXSERV']       = $dadosReceitaO['NRCORAUXFILI'];
                            $pratPadrInserir['QTPADRAOSERV']       = $dadosReceitaO['QTPADRAOPRATTP'] * $percentual / 100;
                            $pratPadrInserir['QTCONTAISERV']       = $dadosReceitaO['QTCONTAIPRATTP'];
                            $pratPadrInserir['HRVALCONSERV']       = $dadosReceitaO['HRVALCONPRATTP'];
                            $pratPadrInserir['NMFANTASIASE']       = $dadosReceitaO['NMFANTASIAPRTP'];
                            // $pratPadrInserir['QTCARBOPRSER']       = $dadosReceitaO['QTCARBOPRFIL'];
                            // $pratPadrInserir['QTLIPIDPRSER']       = $dadosReceitaO['QTLIPIDPRFIL'];
                            // $pratPadrInserir['QTPROTEPRSER']       = $dadosReceitaO['QTPROTEPRFIL'];
                            // $pratPadrInserir['QTCALORPRSER']       = $dadosReceitaO['QTCALORPRFIL'];
                            // $pratPadrInserir['QTALCOOPRSER']       = $dadosReceitaO['QTALCOOPRFIL'];
                            $pratPadrInserir['VRPEMINSERV']        = $dadosReceitaO['VRPEMINPADRTP'];
                            $pratPadrInserir['QTAMOSTRSERV']       = $dadosReceitaO['QTAMOSTRPADRTP'];
                            // $pratPadrInserir['CDPRODPRODUCAO']     = $dadosReceitaO['CDPRODPRODUCAO'];
                            // $pratPadrInserir['QTLIMSEGSERV']       = $dadosReceitaO['QTLIMSEGFILI'];
                            // $pratPadrInserir['IDPRODCHILL']        = $dadosReceitaO['IDPRODCHILL'];
                            // $pratPadrInserir['IDTPPRODCHILL']      = $dadosReceitaO['IDTPPRODCHILL'];
                            // $pratPadrInserir['IDFINALSERV']        = $dadosReceitaO['IDFINALFILI'];
                            // $pratPadrInserir['CDMEDICASE']         = $dadosReceitaO['CDMEDICASE'];
                            // $pratPadrInserir['QTMEDICASEPRATSERV'] = $dadosReceitaO['QTMEDICASEPRATFILI'];
                        break;
                    }
                
                    $requestInsertPrat
                        = new \Zeedhi\Framework\DTO\Request\Row(
                        $pratPadrInserir, '', '', ''
                    );
                    
                    $pratPadrInserir = $this->crudService->getRowsToSave(
                        $requestInsertPrat, "pratserv"
                    );
                    
                    $this->crudService->save("pratserv", $pratPadrInserir);
                }
                
                // Insere Gramagem por Prato
                $gramagPratoInserir = array(
                    'NRORG'         => $nrorg,
                    '__is_new'      => true,
                    'CDFILAUXPRAT'  => $filAuxPrat,
                    'CDPRATO'       => $prato,
                    'CDFILIAL'      => $filialD,
                    'CDSERVFILI'    => $servicoD,
                    'IDORIGEMRECE'  => $tpReceita === 'L' ? 'F' : $tpReceita,
                    'CDFILIALORI'   => $filialO,
                    'CDSERVFILIORI' => $servicoO,
                    'VRPERCENTUAL'  => $percentual
                );

                $requestInsertPrat = new \Zeedhi\Framework\DTO\Request\Row(
                    $gramagPratoInserir, '', '', ''
                );
                $rowsToDeletePratoGramag = $this->crudService->getRowsToDelete(
                    $requestInsertPrat, "pratogramag"
                );
                
                $dataSourcePratoGramag = 'pratogramag';
                $dataSetDeleteGramag = new DataSet($dataSourcePratoGramag, $rowsToDeletePratoGramag);
                $this->crudService->delete($response, $dataSetDeleteGramag);
                
                $gramagPratoInserir = $this->crudService->getRowsToSave(
                    $requestInsertPrat, "pratogramag"
                );
                
                $this->crudService->save("pratogramag", $gramagPratoInserir);
            }
            
            $response->addDataset(new DataSet('RETORNO', array(true)));
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}